{
	"name" : "Sales Management extented with rebates",
	"version" : "1.0",
	"author" : "Tiny",
	"category" : "Generic Modules/Others",
	"website": "http://www.tinyerp.com",
	"depends" : ["base", "sale"],
	"init_xml" : [],
	"update_xml" : ['sale_view.xml'],
	"active": False,
	"installable": False
}
